summaryrefslogtreecommitdiffstats
path: root/src/assets.rs
diff options
context:
space:
mode:
authorVille Skyttä <ville.skytta@iki.fi>2021-08-29 19:19:42 +0300
committerDavid Peter <sharkdp@users.noreply.github.com>2021-08-29 19:55:00 +0200
commit7c41bd72dac7960f40b545002ddc1b0b0aae13d8 (patch)
tree9ad9f64bdbd0a3021dfc91d48e909bf885147bec /src/assets.rs
parent355a82db542dd66539fc0497aad854cdfa668cbe (diff)
assets: add Debian ucf backups to ignored suffixes
Refs https://manpages.debian.org/bullseye/ucf/ucf.1.en.html
Diffstat (limited to 'src/assets.rs')
-rw-r--r--src/assets.rs7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/assets.rs b/src/assets.rs
index 1bfe4f6d..94adf534 100644
--- a/src/assets.rs
+++ b/src/assets.rs
@@ -29,15 +29,18 @@ pub struct SyntaxReferenceInSet<'a> {
pub syntax_set: &'a SyntaxSet,
}
-const IGNORED_SUFFIXES: [&str; 10] = [
+const IGNORED_SUFFIXES: [&str; 13] = [
// Editor etc backups
"~",
".bak",
".old",
".orig",
// Debian and derivatives apt/dpkg backups
".dpkg-dist",
".dpkg-old",
+ ".ucf-dist",
+ ".ucf-new",
+ ".ucf-old",
// Red Hat and derivatives rpm backups
".rpmnew",
".rpmorig",
@@ -29,15 +29,18 @@ pub struct SyntaxReferenceInSet<'a> {
".old",
".orig",
- // Debian and derivatives apt/dpkg backups
+ // Debian and derivatives apt/dpkg/ucf backups
".dpkg-dist",
".dpkg-old",